@@ -1,5 +1,5 @@
 from youtube_autonomous.elements.rules.element_rules import ElementRules
-from youtube_autonomous.segments.enums import EnhancementElementMode
+from youtube_autonomous.segments.enums import EnhancementMode
 
 
 class EffectElementRules(ElementRules):
@@ -23,5 +23,5 @@ class EffectElementRules(ElementRules):
 
         self.can_be_segment = False
         self.can_be_enhancement_element = True
-        self.valid_enhancement_modes = [EnhancementElementMode.REPLACE]
-        self.default_enhancement_mode = EnhancementElementMode.REPLACE
\ No newline at end of file
+        self.valid_enhancement_modes = [EnhancementMode.REPLACE]
+        self.default_enhancement_mode = EnhancementMode.REPLACE
\ No newline at end of file
