@@ -263,7 +263,7 @@ class Segment:
             end = enhancement.start + enhancement.duration
             if enhancement.mode == EnhancementMode.INLINE.value:
                 if enhancement.type in [EnhancementType.EFFECT.value, EnhancementType.EFFECT]:
-                    parameters_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip', 'duration']
+                    parameters_to_ignore = ['self', 'cls', 'args', 'kwargs', 'video', 'duration']
                     parameters_not_from_extra = ['duration']
                     parameters = EffectElementBuilder.get_building_parameters(enhancement, parameters_to_ignore, parameters_not_from_extra)
 
@@ -310,7 +310,7 @@ class Segment:
             elif enhancement.mode == EnhancementMode.REPLACE.value:
                 # I first build the special ones
                 if enhancement.type in [EnhancementType.EFFECT.value, EnhancementType.EFFECT]:
-                    parameters_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip', 'duration']
+                    parameters_to_ignore = ['self', 'cls', 'args', 'kwargs', 'video', 'duration']
                     parameters_not_from_extra = ['duration']
                     parameters = EffectElementBuilder.get_building_parameters(enhancement, parameters_to_ignore, parameters_not_from_extra)
 
