@@ -212,7 +212,7 @@ class YoutubeAutonomous:
                     # We avoid 'duration' because we obtain it from main fields
                     PremadeElementBuilder.extract_extra_params(enhancement, PremadeElementBuilder.premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'duration'])
                 elif enhancement_type == EnhancementType.EFFECT.value:
-                    EffectElementBuilder.extract_extra_params(enhancement, EffectElementBuilder.effect_name_to_class(keywords).apply, params_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip'])
+                    EffectElementBuilder.extract_extra_params(enhancement, EffectElementBuilder.effect_name_to_class(keywords).apply, params_to_ignore = ['self', 'cls', 'args', 'kwargs', 'video'])
                 elif enhancement_type == EnhancementType.TEXT.value:
                     # We avoid 'text' and 'duration' because we obtain them from main fields
                     TextElementBuilder.extract_extra_params(enhancement, TextElementBuilder.text_premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'output_filename', 'duration', 'text'])
